﻿Imports System.Collections.ObjectModel

Public Class DataGridItemsControl

#Region "Items List"
    Private _itemsList = New ObservableCollection(Of String)
    Public ReadOnly Property ItemsList As ObservableCollection(Of String)
        Get
            Return Me._itemsList
        End Get
    End Property
#End Region

#Region "Dependency Properties"
    Public Shared ReadOnly ContentProperty As DependencyProperty = _
                  DependencyProperty.Register("Content", GetType(Object), GetType(DataGridItemsControl))

    Public Property Content() As Object
        Get
            Return GetValue(ContentProperty)
        End Get
        Set(ByVal value As Object)
            SetValue(ContentProperty, value)
        End Set
    End Property
#End Region

#Region "Event Handlers"
    Private Sub DataGridItemsControl_Loaded(sender As Object, e As RoutedEventArgs) Handles Me.Loaded
        ' Bind our Content to the parent objects Content property.
        Dim valueBinding As New Binding("Content")
        valueBinding.RelativeSource = RelativeSource.TemplatedParent
        valueBinding.NotifyOnTargetUpdated = True
        AddHandler Me.TargetUpdated, AddressOf Me.OnTargetUpdated

        Me.SetBinding(DataGridItemsControl.ContentProperty, valueBinding)
    End Sub

    Private Sub OnTargetUpdated(ByVal sender As Object, ByVal e As DataTransferEventArgs)
        ' Clear any existing items.
        Me.Items.Clear()

        ' Providing there is content, split it into a list which this control is bound to.
        If Not String.IsNullOrEmpty(Me.Content) Then
            Dim items() As String = Me.Content.ToString.Split(",")

            For Each item As String In items
                Me.ItemsList.Add(item.Trim)
            Next item

            Me.ItemsSource = Me.ItemsList
        End If
    End Sub
#End Region

End Class
